==> hs-Crypto-4.2.5_1.tbz: lib/ghc-7.4.1/cabal/Crypto-4.2.5/register.sh <==
#!/bin/sh
echo 'name: Crypto
version: 4.2.5
id: Crypto-4.2.5-db147bbfdf94e3aadf7a931355e13c63

license: OtherLicense
copyright: Dominic Steinitz 2003 - 2007
maintainer: Caylee Hogg <caylee.hogg@gmail.com>
stability: Alpha
homepage:
package-url:
synopsis: Collects together existing Haskell cryptographic functions into a package
description: DES, Blowfish, AES, TEA, SHA1, MD5, RSA, BubbleBabble,
             Hexdump, Support for Word128, Word192 and Word256 and Beyond, PKCS5
             Padding, Various Encryption Modes e.g. Cipher Block Chaining all in one package,
             with HUnit and QuickCheck tests, and examples.
category: Cryptography, Codec
author: Dominic Steinitz
exposed: True
exposed-modules: Codec.Binary.BubbleBabble Codec.Encryption.RSA
                 Codec.Encryption.RSA.EMEOAEP Codec.Encryption.RSA.MGF
                 Codec.Encryption.RSA.NumberTheory Codec.Encryption.DES
                 Codec.Encryption.AES Codec.Encryption.TEA Codec.Encryption.Blowfish
                 Codec.Encryption.Modes Codec.Encryption.Padding Codec.Text.Raw
                 Codec.Utils Data.Digest.MD5 Data.Digest.SHA1 Data.Digest.SHA2
                 Data.Digest.SHA224 Data.Digest.SHA256 Data.Digest.SHA384
                 Data.Digest.SHA512 Data.LargeWord Data.HMAC
hidden-modules: Codec.Encryption.BlowfishAux
                Codec.Encryption.DESAux Codec.Encryption.AESAux Data.Digest.MD5Aux
trusted: False
import-dirs: /usr/local/lib/ghc-7.4.1/cabal/Crypto-4.2.5
library-dirs: /usr/local/lib/ghc-7.4.1/cabal/Crypto-4.2.5
              /usr/local/lib
hs-libraries: HSCrypto-4.2.5
extra-libraries:
extra-ghci-libraries:
include-dirs: /usr/local/include
includes:
depends: HUnit-1.2.4.2-5744e904039c3819ba04e12dd2e295dc
         QuickCheck-2.4.2-5e1b443b0b725755bf380173d85ffb73
         array-0.4.0.0-59d1cc0e7979167b002f021942d60f46
         base-4.5.0.0-3459bca6d8e46666b517e8bb2e033728
         pretty-1.1.1.0-74ee6c6be86f83487da68d408cc3ae22
         random-1.0.1.1-7f9342c90214b9289fdaf20c9e2f867f
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/ghc-7.4.1/cabal/Crypto-4.2.5/html/Crypto.haddock
haddock-html: /usr/local/share/doc/ghc-7.4.1/cabal/Crypto-4.2.5/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"

==> hs-Crypto-4.2.5.1_1.tbz: lib/ghc-7.4.2/cabal/Crypto-4.2.5.1/register.sh <==
#!/bin/sh
echo 'name: Crypto
version: 4.2.5.1
id: Crypto-4.2.5.1-3405cb6beefaf8a1963efc74516141d1

license: OtherLicense
copyright: Dominic Steinitz 2003 - 2007
maintainer: Caylee Hogg <caylee.hogg@gmail.com>
stability: Alpha
homepage:
package-url:
synopsis: Collects together existing Haskell cryptographic functions into a package
description: DES, Blowfish, AES, TEA, SHA1, MD5, RSA, BubbleBabble,
             Hexdump, Support for Word128, Word192 and Word256 and Beyond, PKCS5
             Padding, Various Encryption Modes e.g. Cipher Block Chaining all in one package,
             with HUnit and QuickCheck tests, and examples.
category: Cryptography, Codec
author: Dominic Steinitz
exposed: True
exposed-modules: Codec.Binary.BubbleBabble Codec.Encryption.RSA
                 Codec.Encryption.RSA.EMEOAEP Codec.Encryption.RSA.MGF
                 Codec.Encryption.RSA.NumberTheory Codec.Encryption.DES
                 Codec.Encryption.AES Codec.Encryption.TEA Codec.Encryption.Blowfish
                 Codec.Encryption.Modes Codec.Encryption.Padding Codec.Text.Raw
                 Codec.Utils Data.Digest.MD5 Data.Digest.SHA1 Data.Digest.SHA2
                 Data.Digest.SHA224 Data.Digest.SHA256 Data.Digest.SHA384
                 Data.Digest.SHA512 Data.LargeWord Data.HMAC
hidden-modules: Codec.Encryption.BlowfishAux
                Codec.Encryption.DESAux Codec.Encryption.AESAux Data.Digest.MD5Aux
trusted: False
import-dirs: /usr/local/lib/ghc-7.4.2/cabal/Crypto-4.2.5.1
library-dirs: /usr/local/lib/ghc-7.4.2/cabal/Crypto-4.2.5.1
              /usr/local/lib
hs-libraries: HSCrypto-4.2.5.1
extra-libraries:
extra-ghci-libraries:
include-dirs: /usr/local/include
includes:
depends: HUnit-1.2.5.1-04fafbcfa793ac20134c5b9972485d17
         QuickCheck-2.5.1.1-b0101c9f2f49da67b606fa3478ecc4d1
         array-0.4.0.0-4f6c2a594155b0b953c1cf0f54040f61
         base-4.5.1.0-12fddc14a7babb909dd3843e453b5660
         pretty-1.1.1.0-867dcdeb02592f3d2a707618561c7b86
         random-1.0.1.1-fb8963ffa6ffa7a0a448fb912ed467a3
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/ghc-7.4.2/cabal/Crypto-4.2.5.1/html/Crypto.haddock
haddock-html: /usr/local/share/doc/ghc-7.4.2/cabal/Crypto-4.2.5.1/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
